@@ -6,7 +6,7 @@
 #' abundances from and to a \code{.json} file format
 #'
 #' @param fname the path of a \code{.json} file
-#' @return if fname==NULL, returns a \code{.json} string
+#' @return if \code{fname==NULL}, returns a \code{.json} string
 #' @examples
 #' json <- system.file("defaults.json",package="IsoplotR")
 #' settings(json)
@@ -19,7 +19,7 @@ settings <- function(fname=NULL){
     } else {
         prefs <- fromJSON(file=fname)
         .IsoplotR$lambda <- prefs$lambda
-        .IsoplotR$I.R <- prefs$I.R
+        .IsoplotR$iratio <- prefs$iratio
     }
 }
 
@@ -30,8 +30,9 @@ settings <- function(fname=NULL){
 #' @param nuclide the nuclide name
 #' @param x new value for the decay constant
 #' @param e new value for the decay constant uncertainty
-#' @return if x == e == NULL, returns a two-item vector containing the
-#'     decay constant [in Ma-1] and its standard error, respectively.
+#' @return if \code{x==e==NULL}, returns a two-item vector containing
+#'     the decay constant [in Ma-1] and its standard error,
+#'     respectively.
 #' @examples
 #' print(lambda('U238'))
 #' # use the decay constant of Kovarik and Adams (1932)
@@ -55,15 +56,15 @@ lambda <- function(nuclide,x=NULL,e=NULL){
 #'     \code{'Os188Os192'}, \code{'Os189Os192'}
 #' @param x new value for ratio
 #' @param e new value for its standard error
-#' @return if x == e == NULL, returns a two-item vector containing the
-#'     mean value of the requested ratio and its standard error,
+#' @return if \code{x=e=NULL}, returns a two-item vector containing
+#'     the mean value of the requested ratio and its standard error,
 #'     respectively.
 #' @examples
 #' # returns the 238U/235U ratio of Hiess et al. (2012):
-#' print(I.R('U238U235'))
+#' print(iratio('U238U235'))
 #' # use the 238U/235U ratio of Steiger and Jaeger (1977):
-#' I.R('U238U235',138.88,0)
-#' print(I.R('U238U235'))
+#' iratio('U238U235',138.88,0)
+#' print(iratio('U238U235'))
 #' @references
 #' Ar: Lee, Jee-Yon, et al. "A redetermination of the isotopic abundances
 #' of atmospheric Ar." Geochimica et Cosmochimica Acta 70.17 (2006): 4507-4512.
@@ -84,11 +85,11 @@ lambda <- function(nuclide,x=NULL,e=NULL){
 #' "Osmium isotope ratio determinations by negative thermal ionization
 #' mass spectrometry." Int. J. Mass Spect. Ion Proc. 105.2 (1991): 147-159.
 #' 
-#' U: Hiess, Joe, et al. "238U/235U systematics in terrestrial
+#' U: Hiess, Joe, et al. "\eqn{^{238}}U/\eqn{^{235}}U systematics in terrestrial
 #' uranium-bearing minerals." Science 335.6076 (2012): 1610-1614.
 #' @export
-I.R <- function(ratio,x=NULL,e=NULL){
-    if (is.null(x) & is.null(e)) return(.IsoplotR$I.R[[ratio]])
-    if (is.numeric(x)) .IsoplotR$I.R[[ratio]][1] <- x
-    if (is.numeric(e)) .IsoplotR$I.R[[ratio]][2] <- e
+iratio <- function(ratio,x=NULL,e=NULL){
+    if (is.null(x) & is.null(e)) return(.IsoplotR$iratio[[ratio]])
+    if (is.numeric(x)) .IsoplotR$iratio[[ratio]][1] <- x
+    if (is.numeric(e)) .IsoplotR$iratio[[ratio]][2] <- e
 }
