@@ -11,12 +11,12 @@
 #' @examples
 #' x = 99; y = 101;
 #' covmat <- matrix(c(1,0.9,0.9,1),nrow=2)
-#' ell <- get.ellipse(x,y,covmat)
+#' ell <- ellipse(x,y,covmat)
 #' plot(c(90,110),c(90,110),type='l')
 #' polygon(ell,col=rgb(0,1,0,0.5))
 #' points(x,y,pch=21,bg='black')
 #' @export
-get.ellipse <- function(x,y,covmat,alpha=0.05){
+ellipse <- function(x,y,covmat,alpha=0.05){
     nn <- 50
     cutoff <- stats::qchisq(1-alpha,2)
     e <- eigen(covmat)
